% Sweep PRC (power recycling cavity length) in DRFPMI and generate plots.
%
% [xPos, sigDC, fDC] = sweepPRCL(Nsweep)
% see sweepDC for information about the parameters
%
% This displays some DC signals, and some demod signals, during
% a PRC sweep.  From this sweep, one might try to find a good
% signal for PRC.

function [xPos, sigDC, fDC] = osa(Nsweep)

  % Check number of input arguments
  if nargin < 1
    Nsweep = 100;
  elseif nargin > 1
    error('Too Many Arguments!')
  end
  

  % prepare some variables
  sweepSetup


  bar(vFrf/1e6,20*log10(abs(vArf*1e3)))
  xlabel('Modulation Frequency [MHz]')
  ylabel('Field Amplitude (dBmW)')
  colormap(autumn)
  shading faceted

  
  % Error routine for output arguments
  if nargout > 3
    error('Too Many Output Arguments. Max = 3')
  end
  
